==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/MobileAppAssignment.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.complex.DeviceAndAppManagementAssignmentTarget;
import odata.msgraph.client.beta.complex.MobileAppAssignmentSettings;
import odata.msgraph.client.beta.enums.DeviceAndAppManagementAssignmentSource;
import odata.msgraph.client.beta.enums.InstallIntent;


/**
 * <i>“A class containing the properties used for Group Assignment of a Mobile App.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "intent", 
    "target", 
    "settings", 
    "source", 
    "sourceId"})
@JsonInclude(Include.NON_NULL)
public class MobileAppAssignment extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.mobileAppAssignment";
    }

    @JsonProperty("intent")
    protected InstallIntent intent;

    @JsonProperty("target")
    protected DeviceAndAppManagementAssignmentTarget target;

    @JsonProperty("settings")
    protected MobileAppAssignmentSettings settings;

    @JsonProperty("source")
    protected DeviceAndAppManagementAssignmentSource source;

    @JsonProperty("sourceId")
    protected String sourceId;

    protected MobileAppAssignment() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMobileAppAssignment() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private InstallIntent intent;
        private DeviceAndAppManagementAssignmentTarget target;
        private MobileAppAssignmentSettings settings;
        private DeviceAndAppManagementAssignmentSource source;
        private String sourceId;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        /**
         * <i>“The install intent defined by the admin.”</i>
         * 
         * @param intent
         *            value of {@code intent} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder intent(InstallIntent intent) {
            this.intent = intent;
            this.changedFields = changedFields.add("intent");
            return this;
        }

        /**
         * <i>“The target group assignment defined by the admin.”</i>
         * 
         * @param target
         *            value of {@code target} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder target(DeviceAndAppManagementAssignmentTarget target) {
            this.target = target;
            this.changedFields = changedFields.add("target");
            return this;
        }

        /**
         * <i>“The settings for target assignment defined by the admin.”</i>
         * 
         * @param settings
         *            value of {@code settings} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder settings(MobileAppAssignmentSettings settings) {
            this.settings = settings;
            this.changedFields = changedFields.add("settings");
            return this;
        }

        /**
         * <i>“The resource type which is the source for the assignment.”</i>
         * 
         * @param source
         *            value of {@code source} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder source(DeviceAndAppManagementAssignmentSource source) {
            this.source = source;
            this.changedFields = changedFields.add("source");
            return this;
        }

        /**
         * <i>“The identifier of the source of the assignment.”</i>
         * 
         * @param sourceId
         *            value of {@code sourceId} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder sourceId(String sourceId) {
            this.sourceId = sourceId;
            this.changedFields = changedFields.add("sourceId");
            return this;
        }

        public MobileAppAssignment build() {
            MobileAppAssignment _x = new MobileAppAssignment();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.mobileAppAssignment";
            _x.id = id;
            _x.intent = intent;
            _x.target = target;
            _x.settings = settings;
            _x.source = source;
            _x.sourceId = sourceId;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    /**
     * <i>“The install intent defined by the admin.”</i>
     * 
     * @return property intent
     */
    @Property(name="intent")
    @JsonIgnore
    public Optional<InstallIntent> getIntent() {
        return Optional.ofNullable(intent);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code intent} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The install intent defined by the admin.”</i>
     * 
     * @param intent
     *            new value of {@code intent} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code intent} field changed
     */
    public MobileAppAssignment withIntent(InstallIntent intent) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("intent");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.intent = intent;
        return _x;
    }

    /**
     * <i>“The target group assignment defined by the admin.”</i>
     * 
     * @return property target
     */
    @Property(name="target")
    @JsonIgnore
    public Optional<DeviceAndAppManagementAssignmentTarget> getTarget() {
        return Optional.ofNullable(target);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code target} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The target group assignment defined by the admin.”</i>
     * 
     * @param target
     *            new value of {@code target} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code target} field changed
     */
    public MobileAppAssignment withTarget(DeviceAndAppManagementAssignmentTarget target) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("target");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.target = target;
        return _x;
    }

    /**
     * <i>“The settings for target assignment defined by the admin.”</i>
     * 
     * @return property settings
     */
    @Property(name="settings")
    @JsonIgnore
    public Optional<MobileAppAssignmentSettings> getSettings() {
        return Optional.ofNullable(settings);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code settings} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The settings for target assignment defined by the admin.”</i>
     * 
     * @param settings
     *            new value of {@code settings} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code settings} field changed
     */
    public MobileAppAssignment withSettings(MobileAppAssignmentSettings settings) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("settings");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.settings = settings;
        return _x;
    }

    /**
     * <i>“The resource type which is the source for the assignment.”</i>
     * 
     * @return property source
     */
    @Property(name="source")
    @JsonIgnore
    public Optional<DeviceAndAppManagementAssignmentSource> getSource() {
        return Optional.ofNullable(source);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code source} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The resource type which is the source for the assignment.”</i>
     * 
     * @param source
     *            new value of {@code source} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code source} field changed
     */
    public MobileAppAssignment withSource(DeviceAndAppManagementAssignmentSource source) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("source");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.source = source;
        return _x;
    }

    /**
     * <i>“The identifier of the source of the assignment.”</i>
     * 
     * @return property sourceId
     */
    @Property(name="sourceId")
    @JsonIgnore
    public Optional<String> getSourceId() {
        return Optional.ofNullable(sourceId);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code sourceId} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The identifier of the source of the assignment.”</i>
     * 
     * @param sourceId
     *            new value of {@code sourceId} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code sourceId} field changed
     */
    public MobileAppAssignment withSourceId(String sourceId) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("sourceId");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.sourceId = sourceId;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MobileAppAssignment patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        MobileAppAssignment _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MobileAppAssignment put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        MobileAppAssignment _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private MobileAppAssignment _copy() {
        MobileAppAssignment _x = new MobileAppAssignment();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.intent = intent;
        _x.target = target;
        _x.settings = settings;
        _x.source = source;
        _x.sourceId = sourceId;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MobileAppAssignment[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("intent=");
        b.append(this.intent);
        b.append(", ");
        b.append("target=");
        b.append(this.target);
        b.append(", ");
        b.append("settings=");
        b.append(this.settings);
        b.append(", ");
        b.append("source=");
        b.append(this.source);
        b.append(", ");
        b.append("sourceId=");
        b.append(this.sourceId);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/MobileAppAssignment.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.complex.DeviceAndAppManagementAssignmentTarget;
import odata.msgraph.client.beta.complex.MobileAppAssignmentSettings;
import odata.msgraph.client.beta.enums.DeviceAndAppManagementAssignmentSource;
import odata.msgraph.client.beta.enums.InstallIntent;


/**
 * <i>“A class containing the properties used for Group Assignment of a Mobile App.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "intent", 
    "settings", 
    "source", 
    "sourceId", 
    "target"})
@JsonInclude(Include.NON_NULL)
public class MobileAppAssignment extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.mobileAppAssignment";
    }

    @JsonProperty("intent")
    protected InstallIntent intent;

    @JsonProperty("settings")
    protected MobileAppAssignmentSettings settings;

    @JsonProperty("source")
    protected DeviceAndAppManagementAssignmentSource source;

    @JsonProperty("sourceId")
    protected String sourceId;

    @JsonProperty("target")
    protected DeviceAndAppManagementAssignmentTarget target;

    protected MobileAppAssignment() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMobileAppAssignment() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private InstallIntent intent;
        private MobileAppAssignmentSettings settings;
        private DeviceAndAppManagementAssignmentSource source;
        private String sourceId;
        private DeviceAndAppManagementAssignmentTarget target;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        /**
         * <i>“The install intent defined by the admin.”</i>
         * 
         * @param intent
         *            value of {@code intent} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder intent(InstallIntent intent) {
            this.intent = intent;
            this.changedFields = changedFields.add("intent");
            return this;
        }

        /**
         * <i>“The settings for target assignment defined by the admin.”</i>
         * 
         * @param settings
         *            value of {@code settings} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder settings(MobileAppAssignmentSettings settings) {
            this.settings = settings;
            this.changedFields = changedFields.add("settings");
            return this;
        }

        /**
         * <i>“The resource type which is the source for the assignment.”</i>
         * 
         * @param source
         *            value of {@code source} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder source(DeviceAndAppManagementAssignmentSource source) {
            this.source = source;
            this.changedFields = changedFields.add("source");
            return this;
        }

        /**
         * <i>“The identifier of the source of the assignment.”</i>
         * 
         * @param sourceId
         *            value of {@code sourceId} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder sourceId(String sourceId) {
            this.sourceId = sourceId;
            this.changedFields = changedFields.add("sourceId");
            return this;
        }

        /**
         * <i>“The target group assignment defined by the admin.”</i>
         * 
         * @param target
         *            value of {@code target} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder target(DeviceAndAppManagementAssignmentTarget target) {
            this.target = target;
            this.changedFields = changedFields.add("target");
            return this;
        }

        public MobileAppAssignment build() {
            MobileAppAssignment _x = new MobileAppAssignment();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.mobileAppAssignment";
            _x.id = id;
            _x.intent = intent;
            _x.settings = settings;
            _x.source = source;
            _x.sourceId = sourceId;
            _x.target = target;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    /**
     * <i>“The install intent defined by the admin.”</i>
     * 
     * @return property intent
     */
    @Property(name="intent")
    @JsonIgnore
    public Optional<InstallIntent> getIntent() {
        return Optional.ofNullable(intent);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code intent} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The install intent defined by the admin.”</i>
     * 
     * @param intent
     *            new value of {@code intent} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code intent} field changed
     */
    public MobileAppAssignment withIntent(InstallIntent intent) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("intent");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.intent = intent;
        return _x;
    }

    /**
     * <i>“The settings for target assignment defined by the admin.”</i>
     * 
     * @return property settings
     */
    @Property(name="settings")
    @JsonIgnore
    public Optional<MobileAppAssignmentSettings> getSettings() {
        return Optional.ofNullable(settings);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code settings} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The settings for target assignment defined by the admin.”</i>
     * 
     * @param settings
     *            new value of {@code settings} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code settings} field changed
     */
    public MobileAppAssignment withSettings(MobileAppAssignmentSettings settings) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("settings");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.settings = settings;
        return _x;
    }

    /**
     * <i>“The resource type which is the source for the assignment.”</i>
     * 
     * @return property source
     */
    @Property(name="source")
    @JsonIgnore
    public Optional<DeviceAndAppManagementAssignmentSource> getSource() {
        return Optional.ofNullable(source);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code source} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The resource type which is the source for the assignment.”</i>
     * 
     * @param source
     *            new value of {@code source} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code source} field changed
     */
    public MobileAppAssignment withSource(DeviceAndAppManagementAssignmentSource source) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("source");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.source = source;
        return _x;
    }

    /**
     * <i>“The identifier of the source of the assignment.”</i>
     * 
     * @return property sourceId
     */
    @Property(name="sourceId")
    @JsonIgnore
    public Optional<String> getSourceId() {
        return Optional.ofNullable(sourceId);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code sourceId} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The identifier of the source of the assignment.”</i>
     * 
     * @param sourceId
     *            new value of {@code sourceId} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code sourceId} field changed
     */
    public MobileAppAssignment withSourceId(String sourceId) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("sourceId");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.sourceId = sourceId;
        return _x;
    }

    /**
     * <i>“The target group assignment defined by the admin.”</i>
     * 
     * @return property target
     */
    @Property(name="target")
    @JsonIgnore
    public Optional<DeviceAndAppManagementAssignmentTarget> getTarget() {
        return Optional.ofNullable(target);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code target} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“The target group assignment defined by the admin.”</i>
     * 
     * @param target
     *            new value of {@code target} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code target} field changed
     */
    public MobileAppAssignment withTarget(DeviceAndAppManagementAssignmentTarget target) {
        MobileAppAssignment _x = _copy();
        _x.changedFields = changedFields.add("target");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppAssignment");
        _x.target = target;
        return _x;
    }

    public MobileAppAssignment withUnmappedField(String name, Object value) {
        MobileAppAssignment _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MobileAppAssignment patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        MobileAppAssignment _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MobileAppAssignment put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        MobileAppAssignment _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private MobileAppAssignment _copy() {
        MobileAppAssignment _x = new MobileAppAssignment();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.intent = intent;
        _x.settings = settings;
        _x.source = source;
        _x.sourceId = sourceId;
        _x.target = target;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MobileAppAssignment[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("intent=");
        b.append(this.intent);
        b.append(", ");
        b.append("settings=");
        b.append(this.settings);
        b.append(", ");
        b.append("source=");
        b.append(this.source);
        b.append(", ");
        b.append("sourceId=");
        b.append(this.sourceId);
        b.append(", ");
        b.append("target=");
        b.append(this.target);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
